==> vcologen-1.0.2-py3-none-any.whl: vcologen.py <==
# xterm 256 colors
termcolors = [
    (0, 0, 0),
    (128, 0, 0),
    (0, 128, 0),
    (128, 128, 0),
    (0, 0, 128),
    (128, 0, 128),
    (0, 128, 128),
    (192, 192, 192),
    (128, 128, 128),
    (255, 0, 0),
    (0, 255, 0),
    (255, 255, 0),
    (0, 0, 255),
    (255, 0, 255),
    (0, 255, 255),
    (255, 255, 255),
    (0, 0, 0),
    (0, 0, 95),
    (0, 0, 135),
    (0, 0, 175),
    (0, 0, 215),
    (0, 0, 255),
    (0, 95, 0),
    (0, 95, 95),
    (0, 95, 135),
    (0, 95, 175),
    (0, 95, 215),
    (0, 95, 255),
    (0, 135, 0),
    (0, 135, 95),
    (0, 135, 135),
    (0, 135, 175),
    (0, 135, 215),
    (0, 135, 255),
    (0, 175, 0),
    (0, 175, 95),
    (0, 175, 135),
    (0, 175, 175),
    (0, 175, 215),
    (0, 175, 255),
    (0, 215, 0),
    (0, 215, 95),
    (0, 215, 135),
    (0, 215, 175),
    (0, 215, 215),
    (0, 215, 255),
    (0, 255, 0),
    (0, 255, 95),
    (0, 255, 135),
    (0, 255, 175),
    (0, 255, 215),
    (0, 255, 255),
    (95, 0, 0),
    (95, 0, 95),
    (95, 0, 135),
    (95, 0, 175),
    (95, 0, 215),
    (95, 0, 255),
    (95, 95, 0),
    (95, 95, 95),
    (95, 95, 135),
    (95, 95, 175),
    (95, 95, 215),
    (95, 95, 255),
    (95, 135, 0),
    (95, 135, 95),
    (95, 135, 135),
    (95, 135, 175),
    (95, 135, 215),
    (95, 135, 255),
    (95, 175, 0),
    (95, 175, 95),
    (95, 175, 135),
    (95, 175, 175),
    (95, 175, 215),
    (95, 175, 255),
    (95, 215, 0),
    (95, 215, 95),
    (95, 215, 135),
    (95, 215, 175),
    (95, 215, 215),
    (95, 215, 255),
    (95, 255, 0),
    (95, 255, 95),
    (95, 255, 135),
    (95, 255, 175),
    (95, 255, 215),
    (95, 255, 255),
    (135, 0, 0),
    (135, 0, 95),
    (135, 0, 135),
    (135, 0, 175),
    (135, 0, 215),
    (135, 0, 255),
    (135, 95, 0),
    (135, 95, 95),
    (135, 95, 135),
    (135, 95, 175),
    (135, 95, 215),
    (135, 95, 255),
    (135, 135, 0),
    (135, 135, 95),
    (135, 135, 135),
    (135, 135, 175),
    (135, 135, 215),
    (135, 135, 255),
    (135, 175, 0),
    (135, 175, 95),
    (135, 175, 135),
    (135, 175, 175),
    (135, 175, 215),
    (135, 175, 255),
    (135, 215, 0),
    (135, 215, 95),
    (135, 215, 135),
    (135, 215, 175),
    (135, 215, 215),
    (135, 215, 255),
    (135, 255, 0),
    (135, 255, 95),
    (135, 255, 135),
    (135, 255, 175),
    (135, 255, 215),
    (135, 255, 255),
    (175, 0, 0),
    (175, 0, 95),
    (175, 0, 135),
    (175, 0, 175),
    (175, 0, 215),
    (175, 0, 255),
    (175, 95, 0),
    (175, 95, 95),
    (175, 95, 135),
    (175, 95, 175),
    (175, 95, 215),
    (175, 95, 255),
    (175, 135, 0),
    (175, 135, 95),
    (175, 135, 135),
    (175, 135, 175),
    (175, 135, 215),
    (175, 135, 255),
    (175, 175, 0),
    (175, 175, 95),
    (175, 175, 135),
    (175, 175, 175),
    (175, 175, 215),
    (175, 175, 255),
    (175, 215, 0),
    (175, 215, 95),
    (175, 215, 135),
    (175, 215, 175),
    (175, 215, 215),
    (175, 215, 255),
    (175, 255, 0),
    (175, 255, 95),
    (175, 255, 135),
    (175, 255, 175),
    (175, 255, 215),
    (175, 255, 255),
    (215, 0, 0),
    (215, 0, 95),
    (215, 0, 135),
    (215, 0, 175),
    (215, 0, 215),
    (215, 0, 255),
    (215, 95, 0),
    (215, 95, 95),
    (215, 95, 135),
    (215, 95, 175),
    (215, 95, 215),
    (215, 95, 255),
    (215, 135, 0),
    (215, 135, 95),
    (215, 135, 135),
    (215, 135, 175),
    (215, 135, 215),
    (215, 135, 255),
    (215, 175, 0),
    (215, 175, 95),
    (215, 175, 135),
    (215, 175, 175),
    (215, 175, 215),
    (215, 175, 255),
    (215, 215, 0),
    (215, 215, 95),
    (215, 215, 135),
    (215, 215, 175),
    (215, 215, 215),
    (215, 215, 255),
    (215, 255, 0),
    (215, 255, 95),
    (215, 255, 135),
    (215, 255, 175),
    (215, 255, 215),
    (215, 255, 255),
    (255, 0, 0),
    (255, 0, 95),
    (255, 0, 135),
    (255, 0, 175),
    (255, 0, 215),
    (255, 0, 255),
    (255, 95, 0),
    (255, 95, 95),
    (255, 95, 135),
    (255, 95, 175),
    (255, 95, 215),
    (255, 95, 255),
    (255, 135, 0),
    (255, 135, 95),
    (255, 135, 135),
    (255, 135, 175),
    (255, 135, 215),
    (255, 135, 255),
    (255, 175, 0),
    (255, 175, 95),
    (255, 175, 135),
    (255, 175, 175),
    (255, 175, 215),
    (255, 175, 255),
    (255, 215, 0),
    (255, 215, 95),
    (255, 215, 135),
    (255, 215, 175),
    (255, 215, 215),
    (255, 215, 255),
    (255, 255, 0),
    (255, 255, 95),
    (255, 255, 135),
    (255, 255, 175),
    (255, 255, 215),
    (255, 255, 255),
    (8, 8, 8),
    (18, 18, 18),
    (28, 28, 28),
    (38, 38, 38),
    (48, 48, 48),
    (58, 58, 58),
    (68, 68, 68),
    (78, 78, 78),
    (88, 88, 88),
    (98, 98, 98),
    (108, 108, 108),
    (118, 118, 118),
    (128, 128, 128),
    (138, 138, 138),
    (148, 148, 148),
    (158, 158, 158),
    (168, 168, 168),
    (178, 178, 178),
    (188, 188, 188),
    (198, 198, 198),
    (208, 208, 208),
    (218, 218, 218),
    (228, 228, 228),
    (238, 238, 238),
]


# find near 256color by hex
def hex_to_256c(hexcolor):
    hexcolor = hexcolor.strip("#")
    rgb = (int(hexcolor[:2], 16), int(hexcolor[2:4], 16), int(hexcolor[4:], 16))
    color = 0
    min_dist = 765
    for i in range(256):
        dist = 0
        for j in range(3):
            dist += ((termcolors[i][j] - rgb[j]) ** 2) ** 0.5
        if dist < min_dist:
            color = i
            min_dist = dist
    return color


TEMPLATE = """
hi clear
if exists('syntax_on')
  syntax reset
endif

let g:colors_name = '{name}'
set background=dark

hi Normal ctermbg={c_colors[0]} ctermfg={c_colors[1]} cterm=NONE guibg={colors[0]} guifg={colors[1]} gui=NONE
hi NonText ctermbg={c_colors[0]} ctermfg={c_colors[10]} cterm=NONE guibg={colors[0]} guifg={colors[10]} gui=NONE
hi Comment ctermbg={c_colors[0]} ctermfg={c_colors[10]} cterm=NONE guibg={colors[0]} guifg={colors[10]} gui=NONE
hi Conceal ctermbg={c_colors[0]} ctermfg={c_colors[10]} cterm=NONE guibg={colors[0]} guifg={colors[10]} gui=NONE
hi Constant ctermbg={c_colors[0]} ctermfg={c_colors[7]} cterm=NONE guibg={colors[0]} guifg={colors[7]} gui=NONE
hi Identifier ctermbg={c_colors[0]} ctermfg={c_colors[17]} cterm=NONE guibg={colors[0]} guifg={colors[17]} gui=NONE
hi Statement ctermbg={c_colors[0]} ctermfg={c_colors[10]} cterm=NONE guibg={colors[0]} guifg={colors[10]} gui=NONE
hi Operator ctermbg={c_colors[0]} ctermfg={c_colors[17]} cterm=NONE guibg={colors[0]} guifg={colors[17]} gui=NONE
hi PreProc ctermbg={c_colors[0]} ctermfg={c_colors[10]} cterm=NONE guibg={colors[0]} guifg={colors[10]} gui=NONE
hi Type ctermbg={c_colors[0]} ctermfg={c_colors[17]} cterm=NONE guibg={colors[0]} guifg={colors[17]} gui=NONE
hi Special ctermbg=NONE ctermfg={c_colors[10]} cterm=NONE
hi Special guibg=NONE guifg={colors[10]} gui=NONE ctermbg=NONE ctermfg={colors[3]} cterm=NONE
hi Warning ctermbg=NONE ctermfg={c_colors[5]} cterm=NONE
hi Warning guibg=NONE guifg={colors[5]} gui=NONE ctermbg=NONE ctermfg={colors[10]} cterm=NONE
hi Todo ctermbg=NONE ctermfg={c_colors[11]} cterm=bold
hi Todo guibg=NONE guifg={colors[11]} gui=bold ctermbg=NONE ctermfg={colors[17]} cterm=underline
hi StatusLine ctermbg={c_colors[10]} ctermfg={c_colors[7]} cterm=NONE guibg={colors[10]} guifg={colors[7]} gui=NONE
hi StatusLineNC ctermbg={c_colors[10]} ctermfg={c_colors[10]} cterm=NONE guibg={colors[10]} guifg={colors[10]} gui=NONE
hi WildMenu ctermbg={c_colors[10]} ctermfg={c_colors[11]} cterm=NONE guibg={colors[10]} guifg={colors[11]} gui=NONE
hi VertSplit ctermbg={c_colors[10]} ctermfg={c_colors[10]} cterm=NONE guibg={colors[10]} guifg={colors[10]} gui=NONE
hi Title ctermbg=NONE ctermfg={c_colors[17]} cterm=bold
hi Title guibg=NONE guifg={colors[17]} gui=bold ctermbg=NONE ctermfg={colors[10]} cterm=NONE
hi CursorLineNr ctermbg={c_colors[10]} ctermfg={c_colors[7]} cterm=NONE guibg={colors[10]} guifg={colors[7]} gui=NONE
hi Cursor ctermbg={c_colors[7]} ctermfg={c_colors[17]} cterm=NONE guibg={colors[7]} guifg={colors[17]} gui=NONE
hi CursorLine ctermbg={c_colors[10]} ctermfg=NONE cterm=NONE
hi CursorLine guibg={colors[10]} guifg=NONE gui=NONE ctermbg={colors[2]} ctermfg=NONE cterm=NONE
hi SignColumn ctermbg=NONE ctermfg={c_colors[10]} cterm=NONE
hi SignColumn guibg=NONE guifg={colors[10]} gui=NONE ctermbg={colors[10]} ctermfg=NONE cterm=NONE
hi VisualNOS ctermbg={c_colors[10]} ctermfg=NONE cterm=NONE
hi VisualNOS guibg={colors[10]} guifg=NONE gui=NONE ctermbg={colors[10]} ctermfg=NONE cterm=NONE
hi PmenuSbar ctermbg={c_colors[10]} ctermfg=NONE cterm=NONE
hi PmenuSbar guibg={colors[10]} guifg=NONE gui=NONE ctermbg={colors[10]} ctermfg={c_colors[7]} cterm=NONE
hi PmenuThumb ctermbg={c_colors[11]} ctermfg=NONE cterm=NONE
hi PmenuThumb guibg={colors[11]} guifg=NONE gui=NONE ctermbg=NONE ctermfg={colors[10]} cterm=NONE
hi Folded ctermbg={c_colors[2]} ctermfg={c_colors[10]} cterm=NONE guibg={colors[2]} guifg={colors[10]} gui=NONE
hi SpecialKey ctermbg=NONE ctermfg={c_colors[10]} cterm=NONE
hi SpecialKey guibg=NONE guifg={colors[10]} gui=NONE ctermbg={colors[11]} ctermfg={c_colors[2]} cterm=NONE
hi Search ctermbg={c_colors[7]} ctermfg={c_colors[2]} cterm=NONE guibg={colors[7]} guifg={colors[2]} gui=NONE
hi Directory ctermbg=NONE ctermfg={c_colors[7]} cterm=NONE
hi Directory guibg=NONE guifg={colors[7]} gui=NONE ctermbg=NONE ctermfg={colors[11]} cterm=bold
hi SpellBad ctermbg=NONE ctermfg={c_colors[3]} cterm=underline
hi SpellBad guibg=NONE guifg={colors[3]} gui=underline ctermbg=NONE ctermfg={colors[4]} cterm=underline
hi SpellLocal ctermbg=NONE ctermfg={c_colors[5]} cterm=underline
hi SpellLocal guibg=NONE guifg={colors[5]} gui=underline ctermbg={colors[2]} ctermfg=NONE cterm=NONE
hi DiffAdd ctermbg={c_colors[10]} ctermfg={c_colors[4]} cterm=NONE guibg={colors[10]} guifg={colors[4]} gui=NONE
hi DiffChange ctermbg={c_colors[10]} ctermfg=NONE cterm=NONE
hi DiffChange guibg={colors[10]} guifg=NONE gui=NONE ctermbg={colors[10]} ctermfg={c_colors[3]} cterm=NONE
hi DiffText ctermbg={c_colors[10]} ctermfg={c_colors[5]} cterm=NONE guibg={colors[10]} guifg={colors[5]} gui=NONE
hi helpHyperTextJump ctermbg={c_colors[0]} ctermfg={c_colors[7]} cterm=NONE guibg={colors[0]} guifg={colors[7]} gui=NONE
"""


def generate(name, colors, template=TEMPLATE):
    c_colors = [hex_to_256c(c) for c in colors]
    return template.format(name=name, colors=colors, c_colors=c_colors)

==> vcologen-1.0.3-py3-none-any.whl: vcologen.py <==
# xterm 256 colors
termcolors = [
    (0, 0, 0),
    (128, 0, 0),
    (0, 128, 0),
    (128, 128, 0),
    (0, 0, 128),
    (128, 0, 128),
    (0, 128, 128),
    (192, 192, 192),
    (128, 128, 128),
    (255, 0, 0),
    (0, 255, 0),
    (255, 255, 0),
    (0, 0, 255),
    (255, 0, 255),
    (0, 255, 255),
    (255, 255, 255),
    (0, 0, 0),
    (0, 0, 95),
    (0, 0, 135),
    (0, 0, 175),
    (0, 0, 215),
    (0, 0, 255),
    (0, 95, 0),
    (0, 95, 95),
    (0, 95, 135),
    (0, 95, 175),
    (0, 95, 215),
    (0, 95, 255),
    (0, 135, 0),
    (0, 135, 95),
    (0, 135, 135),
    (0, 135, 175),
    (0, 135, 215),
    (0, 135, 255),
    (0, 175, 0),
    (0, 175, 95),
    (0, 175, 135),
    (0, 175, 175),
    (0, 175, 215),
    (0, 175, 255),
    (0, 215, 0),
    (0, 215, 95),
    (0, 215, 135),
    (0, 215, 175),
    (0, 215, 215),
    (0, 215, 255),
    (0, 255, 0),
    (0, 255, 95),
    (0, 255, 135),
    (0, 255, 175),
    (0, 255, 215),
    (0, 255, 255),
    (95, 0, 0),
    (95, 0, 95),
    (95, 0, 135),
    (95, 0, 175),
    (95, 0, 215),
    (95, 0, 255),
    (95, 95, 0),
    (95, 95, 95),
    (95, 95, 135),
    (95, 95, 175),
    (95, 95, 215),
    (95, 95, 255),
    (95, 135, 0),
    (95, 135, 95),
    (95, 135, 135),
    (95, 135, 175),
    (95, 135, 215),
    (95, 135, 255),
    (95, 175, 0),
    (95, 175, 95),
    (95, 175, 135),
    (95, 175, 175),
    (95, 175, 215),
    (95, 175, 255),
    (95, 215, 0),
    (95, 215, 95),
    (95, 215, 135),
    (95, 215, 175),
    (95, 215, 215),
    (95, 215, 255),
    (95, 255, 0),
    (95, 255, 95),
    (95, 255, 135),
    (95, 255, 175),
    (95, 255, 215),
    (95, 255, 255),
    (135, 0, 0),
    (135, 0, 95),
    (135, 0, 135),
    (135, 0, 175),
    (135, 0, 215),
    (135, 0, 255),
    (135, 95, 0),
    (135, 95, 95),
    (135, 95, 135),
    (135, 95, 175),
    (135, 95, 215),
    (135, 95, 255),
    (135, 135, 0),
    (135, 135, 95),
    (135, 135, 135),
    (135, 135, 175),
    (135, 135, 215),
    (135, 135, 255),
    (135, 175, 0),
    (135, 175, 95),
    (135, 175, 135),
    (135, 175, 175),
    (135, 175, 215),
    (135, 175, 255),
    (135, 215, 0),
    (135, 215, 95),
    (135, 215, 135),
    (135, 215, 175),
    (135, 215, 215),
    (135, 215, 255),
    (135, 255, 0),
    (135, 255, 95),
    (135, 255, 135),
    (135, 255, 175),
    (135, 255, 215),
    (135, 255, 255),
    (175, 0, 0),
    (175, 0, 95),
    (175, 0, 135),
    (175, 0, 175),
    (175, 0, 215),
    (175, 0, 255),
    (175, 95, 0),
    (175, 95, 95),
    (175, 95, 135),
    (175, 95, 175),
    (175, 95, 215),
    (175, 95, 255),
    (175, 135, 0),
    (175, 135, 95),
    (175, 135, 135),
    (175, 135, 175),
    (175, 135, 215),
    (175, 135, 255),
    (175, 175, 0),
    (175, 175, 95),
    (175, 175, 135),
    (175, 175, 175),
    (175, 175, 215),
    (175, 175, 255),
    (175, 215, 0),
    (175, 215, 95),
    (175, 215, 135),
    (175, 215, 175),
    (175, 215, 215),
    (175, 215, 255),
    (175, 255, 0),
    (175, 255, 95),
    (175, 255, 135),
    (175, 255, 175),
    (175, 255, 215),
    (175, 255, 255),
    (215, 0, 0),
    (215, 0, 95),
    (215, 0, 135),
    (215, 0, 175),
    (215, 0, 215),
    (215, 0, 255),
    (215, 95, 0),
    (215, 95, 95),
    (215, 95, 135),
    (215, 95, 175),
    (215, 95, 215),
    (215, 95, 255),
    (215, 135, 0),
    (215, 135, 95),
    (215, 135, 135),
    (215, 135, 175),
    (215, 135, 215),
    (215, 135, 255),
    (215, 175, 0),
    (215, 175, 95),
    (215, 175, 135),
    (215, 175, 175),
    (215, 175, 215),
    (215, 175, 255),
    (215, 215, 0),
    (215, 215, 95),
    (215, 215, 135),
    (215, 215, 175),
    (215, 215, 215),
    (215, 215, 255),
    (215, 255, 0),
    (215, 255, 95),
    (215, 255, 135),
    (215, 255, 175),
    (215, 255, 215),
    (215, 255, 255),
    (255, 0, 0),
    (255, 0, 95),
    (255, 0, 135),
    (255, 0, 175),
    (255, 0, 215),
    (255, 0, 255),
    (255, 95, 0),
    (255, 95, 95),
    (255, 95, 135),
    (255, 95, 175),
    (255, 95, 215),
    (255, 95, 255),
    (255, 135, 0),
    (255, 135, 95),
    (255, 135, 135),
    (255, 135, 175),
    (255, 135, 215),
    (255, 135, 255),
    (255, 175, 0),
    (255, 175, 95),
    (255, 175, 135),
    (255, 175, 175),
    (255, 175, 215),
    (255, 175, 255),
    (255, 215, 0),
    (255, 215, 95),
    (255, 215, 135),
    (255, 215, 175),
    (255, 215, 215),
    (255, 215, 255),
    (255, 255, 0),
    (255, 255, 95),
    (255, 255, 135),
    (255, 255, 175),
    (255, 255, 215),
    (255, 255, 255),
    (8, 8, 8),
    (18, 18, 18),
    (28, 28, 28),
    (38, 38, 38),
    (48, 48, 48),
    (58, 58, 58),
    (68, 68, 68),
    (78, 78, 78),
    (88, 88, 88),
    (98, 98, 98),
    (108, 108, 108),
    (118, 118, 118),
    (128, 128, 128),
    (138, 138, 138),
    (148, 148, 148),
    (158, 158, 158),
    (168, 168, 168),
    (178, 178, 178),
    (188, 188, 188),
    (198, 198, 198),
    (208, 208, 208),
    (218, 218, 218),
    (228, 228, 228),
    (238, 238, 238),
]


# find near 256color by hex
def hex_to_256c(hexcolor):
    hexcolor = hexcolor.strip("#")
    rgb = (int(hexcolor[:2], 16), int(hexcolor[2:4], 16), int(hexcolor[4:], 16))
    color = 0
    min_dist = 765
    for i in range(256):
        dist = 0
        for j in range(3):
            dist += ((termcolors[i][j] - rgb[j]) ** 2) ** 0.5
        if dist < min_dist:
            color = i
            min_dist = dist
    return color


TEMPLATE = """
hi clear
if exists('syntax_on')
  syntax reset
endif

let g:colors_name = '{name}'
set background=dark

hi Normal ctermbg={c_colors[2]} ctermfg={c_colors[17]} cterm=NONE guibg={colors[2]} guifg={colors[17]} gui=NONE
hi NonText ctermbg={c_colors[0]} ctermfg={c_colors[10]} cterm=NONE guibg={colors[0]} guifg={colors[10]} gui=NONE
hi Comment ctermbg={c_colors[0]} ctermfg={c_colors[10]} cterm=NONE guibg={colors[0]} guifg={colors[10]} gui=NONE
hi Conceal ctermbg={c_colors[0]} ctermfg={c_colors[10]} cterm=NONE guibg={colors[0]} guifg={colors[10]} gui=NONE
hi Constant ctermbg={c_colors[0]} ctermfg={c_colors[7]} cterm=NONE guibg={colors[0]} guifg={colors[7]} gui=NONE
hi Identifier ctermbg={c_colors[0]} ctermfg={c_colors[17]} cterm=NONE guibg={colors[0]} guifg={colors[17]} gui=NONE
hi Statement ctermbg={c_colors[0]} ctermfg={c_colors[10]} cterm=NONE guibg={colors[0]} guifg={colors[10]} gui=NONE
hi Operator ctermbg={c_colors[0]} ctermfg={c_colors[17]} cterm=NONE guibg={colors[0]} guifg={colors[17]} gui=NONE
hi PreProc ctermbg={c_colors[0]} ctermfg={c_colors[10]} cterm=NONE guibg={colors[0]} guifg={colors[10]} gui=NONE
hi Type ctermbg={c_colors[0]} ctermfg={c_colors[17]} cterm=NONE guibg={colors[0]} guifg={colors[17]} gui=NONE
hi Special ctermbg=NONE ctermfg={c_colors[10]} cterm=NONE guibg=NONE guifg={colors[10]} gui=NONE
hi Error ctermbg=NONE ctermfg=darkred cterm=NONE guibg=NONE guifg=darkred gui=NONE
hi Warning ctermbg=NONE ctermfg={c_colors[5]} cterm=NONE guibg=NONE guifg={colors[5]} gui=NONE
hi ModeMsg ctermbg=NONE ctermfg={c_colors[10]} cterm=NONE guibg=NONE guifg={colors[10]} gui=NONE
hi Todo ctermbg=NONE ctermfg={c_colors[11]} cterm=bold guibg=NONE guifg={colors[11]} gui=bold
hi Underlined ctermbg=NONE ctermfg={c_colors[17]} cterm=underline guibg=NONE guifg={colors[17]} gui=underline
hi StatusLine ctermbg={c_colors[10]} ctermfg={c_colors[7]} cterm=NONE guibg={colors[10]} guifg={colors[7]} gui=NONE
hi StatusLineNC ctermbg={c_colors[10]} ctermfg={c_colors[10]} cterm=NONE guibg={colors[10]} guifg={colors[10]} gui=NONE
hi WildMenu ctermbg={c_colors[10]} ctermfg={c_colors[11]} cterm=NONE guibg={colors[10]} guifg={colors[11]} gui=NONE
hi VertSplit ctermbg={c_colors[10]} ctermfg={c_colors[10]} cterm=NONE guibg={colors[10]} guifg={colors[10]} gui=NONE
hi Title ctermbg=NONE ctermfg={c_colors[17]} cterm=bold guibg=NONE guifg={colors[17]} gui=bold
hi LineNr ctermbg=NONE ctermfg={c_colors[10]} cterm=NONE guibg=NONE guifg={colors[10]} gui=NONE
hi CursorLineNr ctermbg={c_colors[10]} ctermfg={c_colors[7]} cterm=NONE guibg={colors[10]} guifg={colors[7]} gui=NONE
hi Cursor ctermbg={c_colors[7]} ctermfg={c_colors[17]} cterm=NONE guibg={colors[7]} guifg={colors[17]} gui=NONE
hi CursorLine ctermbg={c_colors[10]} ctermfg=NONE cterm=NONE guibg={colors[10]} guifg=NONE gui=NONE
hi ColorColumn ctermbg={c_colors[2]} ctermfg=NONE cterm=NONE guibg={colors[2]} guifg=NONE gui=NONE
hi SignColumn ctermbg=NONE ctermfg={c_colors[10]} cterm=NONE guibg=NONE guifg={colors[10]} gui=NONE
hi Visual ctermbg={c_colors[10]} ctermfg=NONE cterm=NONE guibg={colors[10]} guifg=NONE gui=NONE
hi VisualNOS ctermbg={c_colors[10]} ctermfg=NONE cterm=NONE guibg={colors[10]} guifg=NONE gui=NONE
hi Pmenu ctermbg={c_colors[10]} ctermfg=NONE cterm=NONE guibg={colors[10]} guifg=NONE gui=NONE
hi PmenuSbar ctermbg={c_colors[10]} ctermfg=NONE cterm=NONE guibg={colors[10]} guifg=NONE gui=NONE
hi PmenuSel ctermbg={c_colors[10]} ctermfg={c_colors[7]} cterm=NONE guibg={colors[10]} guifg={colors[7]} gui=NONE
hi PmenuThumb ctermbg={c_colors[11]} ctermfg=NONE cterm=NONE guibg={colors[11]} guifg=NONE gui=NONE
hi FoldColumn ctermbg=NONE ctermfg={c_colors[10]} cterm=NONE guibg=NONE guifg={colors[10]} gui=NONE
hi Folded ctermbg={c_colors[2]} ctermfg={c_colors[10]} cterm=NONE guibg={colors[2]} guifg={colors[10]} gui=NONE
hi SpecialKey ctermbg=NONE ctermfg={c_colors[10]} cterm=NONE guibg=NONE guifg={colors[10]} gui=NONE
hi IncSearch ctermbg={c_colors[11]} ctermfg={c_colors[2]} cterm=NONE guibg={colors[11]} guifg={colors[2]} gui=NONE
hi Search ctermbg={c_colors[7]} ctermfg={c_colors[2]} cterm=NONE guibg={colors[7]} guifg={colors[2]} gui=NONE
hi Directory ctermbg=NONE ctermfg={c_colors[7]} cterm=NONE guibg=NONE guifg={colors[7]} gui=NONE
hi MatchParen ctermbg=NONE ctermfg={c_colors[11]} cterm=bold guibg=NONE guifg={colors[11]} gui=bold
hi SpellBad ctermbg=NONE ctermfg=darkred cterm=underline guibg=NONE guifg=darkred gui=underline
hi SpellCap ctermbg=NONE ctermfg={c_colors[4]} cterm=underline guibg=NONE guifg={colors[4]} gui=underline
hi SpellLocal ctermbg=NONE ctermfg={c_colors[5]} cterm=underline guibg=NONE guifg={colors[5]} gui=underline
hi QuickFixLine ctermbg={c_colors[2]} ctermfg=NONE cterm=NONE guibg={colors[2]} guifg=NONE gui=NONE
hi DiffAdd ctermbg={c_colors[10]} ctermfg={c_colors[4]} cterm=NONE guibg={colors[10]} guifg={colors[4]} gui=NONE
hi DiffChange ctermbg={c_colors[10]} ctermfg=NONE cterm=NONE guibg={colors[10]} guifg=NONE gui=NONE
hi DiffDelete ctermbg={c_colors[10]} ctermfg=darkred cterm=NONE guibg={colors[10]} guifg=darkred gui=NONE
hi DiffText ctermbg={c_colors[10]} ctermfg={c_colors[5]} cterm=NONE guibg={colors[10]} guifg={colors[5]} gui=NONE
hi helpHyperTextJump ctermbg={c_colors[0]} ctermfg={c_colors[7]} cterm=NONE guibg={colors[0]} guifg={colors[7]} gui=NONE
"""


def generate(name, colors, template=TEMPLATE):
    c_colors = [hex_to_256c(c) for c in colors]
    return template.format(name=name, colors=colors, c_colors=c_colors)
